@@ -268,13 +268,8 @@ static inline int pathendswith(const char *path, const char *basenam) {
    Allocate as needed. Return 0 on success, -1 on failure */
 int pathjoin(char **path, int nseg, ...);
 
-/* Call calloc to allocate an array of N instances of *VAR */
-#define CALLOC(Var,N) do { (Var) = calloc ((N), sizeof (*(Var))); } while (0)
-
 #define MEMZERO(ptr, n) memset((ptr), 0, (n) * sizeof(*(ptr)));
 
-#define MEMCPY(dest, src, n) memcpy((dest), (src), (n) * sizeof(*(src)))
-
 #define MEMMOVE(dest, src, n) memmove((dest), (src), (n) * sizeof(*(src)))
 
 /**
