@@ -1,8 +1,9 @@
-/* A Bison parser, made by GNU Bison 3.0.4.  */
+/* A Bison parser, made by GNU Bison 3.8.2.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
+   Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,7 +16,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -30,6 +31,10 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
+/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
+   especially those whose name start with YY_ or yy_.  They are
+   private implementation details that can be changed or removed.  */
+
 #ifndef YY_AUGL_PARSER_H_INCLUDED
 # define YY_AUGL_PARSER_H_INCLUDED
 /* Debug traces.  */
@@ -40,32 +45,41 @@
 extern int augl_debug;
 #endif
 
-/* Token type.  */
+/* Token kinds.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
   enum yytokentype
   {
-    DQUOTED = 258,
-    REGEXP = 259,
-    LIDENT = 260,
-    UIDENT = 261,
-    QIDENT = 262,
-    ARROW = 263,
-    KW_MODULE = 264,
-    KW_AUTOLOAD = 265,
-    KW_LET = 266,
-    KW_LET_REC = 267,
-    KW_IN = 268,
-    KW_STRING = 269,
-    KW_REGEXP = 270,
-    KW_LENS = 271,
-    KW_TEST = 272,
-    KW_GET = 273,
-    KW_PUT = 274,
-    KW_AFTER = 275
+    YYEMPTY = -2,
+    YYEOF = 0,                     /* "end of file"  */
+    YYerror = 256,                 /* error  */
+    YYUNDEF = 257,                 /* "invalid token"  */
+    DQUOTED = 258,                 /* DQUOTED  */
+    REGEXP = 259,                  /* REGEXP  */
+    LIDENT = 260,                  /* LIDENT  */
+    UIDENT = 261,                  /* UIDENT  */
+    QIDENT = 262,                  /* QIDENT  */
+    ARROW = 263,                   /* ARROW  */
+    KW_MODULE = 264,               /* KW_MODULE  */
+    KW_AUTOLOAD = 265,             /* KW_AUTOLOAD  */
+    KW_LET = 266,                  /* KW_LET  */
+    KW_LET_REC = 267,              /* KW_LET_REC  */
+    KW_IN = 268,                   /* KW_IN  */
+    KW_STRING = 269,               /* KW_STRING  */
+    KW_REGEXP = 270,               /* KW_REGEXP  */
+    KW_LENS = 271,                 /* KW_LENS  */
+    KW_TEST = 272,                 /* KW_TEST  */
+    KW_GET = 273,                  /* KW_GET  */
+    KW_PUT = 274,                  /* KW_PUT  */
+    KW_AFTER = 275                 /* KW_AFTER  */
   };
+  typedef enum yytokentype yytoken_kind_t;
 #endif
-/* Tokens.  */
+/* Token kinds.  */
+#define YYEMPTY -2
+#define YYEOF 0
+#define YYerror 256
+#define YYUNDEF 257
 #define DQUOTED 258
 #define REGEXP 259
 #define LIDENT 260
@@ -87,10 +101,9 @@ extern int augl_debug;
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-
 union YYSTYPE
 {
-#line 89 "parser.y" /* yacc.c:1909  */
+#line 89 "parser.y"
 
   struct term    *term;
   struct type    *type;
@@ -104,9 +117,9 @@ union YYSTYPE
   int            intval;
   enum quant_tag quant;
 
-#line 108 "parser.h" /* yacc.c:1909  */
-};
+#line 121 "parser.h"
 
+};
 typedef union YYSTYPE YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define YYSTYPE_IS_DECLARED 1
@@ -128,9 +141,11 @@ struct YYLTYPE
 
 
 
+
 int augl_parse (struct term **term, yyscan_t scanner);
+
 /* "%code provides" blocks.  */
-#line 46 "parser.y" /* yacc.c:1909  */
+#line 46 "parser.y"
 
 #include "info.h"
 
@@ -141,6 +156,6 @@ struct state {
 };
 
 
-#line 145 "parser.h" /* yacc.c:1909  */
+#line 160 "parser.h"
 
 #endif /* !YY_AUGL_PARSER_H_INCLUDED  */
